package com.ruoyi.bst.app.service;

import com.ruoyi.bst.app.domain.App;
import com.ruoyi.bst.app.domain.AppQuery;
import com.ruoyi.bst.app.domain.AppVO;
import com.ruoyi.bst.app.domain.vo.AppAllVO;

import java.util.List;

/**
 * APP信息Service接口
 *
 * @author ruoyi
 * @date 2025-01-08
 */
public interface AppService
{
    /**
     * 查询APP信息
     *
     * @param id APP信息主键
     * @return APP信息
     */
    public AppVO selectAppById(Long id);

    /**
     * 查询APP信息列表
     *
     * @param app APP信息
     * @return APP信息集合
     */
    public List<AppVO> selectAppList(AppQuery app);

    /**
     * 新增APP信息
     *
     * @param app APP信息
     * @return 结果
     */
    public int insertApp(App app);

    /**
     * 修改APP信息
     *
     * @param app APP信息
     * @return 结果
     */
    public int updateApp(App app);

    /**
     * 批量删除APP信息
     *
     * @param ids 需要删除的APP信息主键集合
     * @return 结果
     */
    public int deleteAppByIds(Long[] ids);

    /**
     * 删除APP信息信息
     *
     * @param id APP信息主键
     * @return 结果
     */
    public int deleteAppById(Long id);

    /**
     * 根据id集合查询
     * @param ids
     * @return
     */
    List<AppVO> selectByIds(List<Long> ids);

    /**
     * 查询所有APP信息
     * @return
     */
    List<AppAllVO> selectAll();
}
